@@ -40,7 +40,11 @@ ogr2osm is based very heavily on code released under the following terms:
 ###############################################################################
 '''
 
-import sys, os, argparse, logging, inspect
+import sys
+import os
+import argparse
+import logging
+import inspect
 
 from .version import __program__, __version__
 from .translation_base_class import TranslationBase
@@ -50,11 +54,9 @@ from .osm_data import OsmData
 from .osm_datawriter import OsmDataWriter
 from .pbf_datawriter import is_protobuf_installed, PbfDataWriter
 
-logging.basicConfig(format="%(message)s", level = logging.DEBUG)
-
-def parse_commandline():
+def parse_commandline(logger):
     parser = argparse.ArgumentParser(prog=__program__)
-    
+
     #parser.add_argument("-v", "--verbose", dest="verbose", action="store_true")
     #parser.add_argument("-d", "--debug-tags", dest="debugTags", action="store_true",
     #                    help="Output the tags for every feature parsed.")
@@ -126,6 +128,8 @@ def parse_commandline():
                              "Implies upload=\"never\" and download=\"never\".")
     parser.add_argument("--add-bounds", dest="addBounds", action="store_true",
                         help="Add boundaries to output file")
+    parser.add_argument("--suppress-empty-tags", dest="suppressEmptyTags", action="store_true",
+                        help="Suppress empty tags")
     parser.add_argument("--add-version", dest="addVersion", action="store_true",
                         help=argparse.SUPPRESS) # can cause problems when used inappropriately
     parser.add_argument("--add-timestamp", dest="addTimestamp", action="store_true",
@@ -136,10 +140,10 @@ def parse_commandline():
                              "string such as: \"PG:dbname=pdx_bldgs user=emma host=localhost\" " +
                              "(including the quotes)")
     params = parser.parse_args()
-    
+
     if not is_protobuf_installed:
         params.pbf = False
-    
+
     if params.outputFile:
         params.outputFile = os.path.realpath(params.outputFile)
 
@@ -160,36 +164,35 @@ def parse_commandline():
         else:
             (base, ext) = os.path.splitext(params.outputFile)
             if params.pbf and ext.lower() == '.osm':
-                logging.warning("WARNING: You specified PBF output with --pbf " +
-                                "but the outputfile has extension .osm, " +
-                                "ignoring --pbf parameter")
+                logger.warning("WARNING: You specified PBF output with --pbf "
+                               "but the outputfile has extension .osm, "
+                               "ignoring --pbf parameter")
                 params.pbf = False
             elif is_protobuf_installed and not params.pbf and ext.lower() == '.pbf':
-                logging.warning("WARNING: You didn't specify PBF output with --pbf " +
-                                "but the outputfile has extension .pbf, " +
-                                "automatically setting --pbf parameter")
+                logger.warning("WARNING: You didn't specify PBF output with --pbf "
+                               "but the outputfile has extension .pbf, "
+                               "automatically setting --pbf parameter")
                 params.pbf = True
             elif not is_protobuf_installed and not params.pbf and ext.lower() == '.pbf':
-                logging.warning("WARNING: PBF output is not supported on this " +
-                                "system but the outputfile has extension .pbf, " +
-                                "automatically removing .pbf extension")
+                logger.warning("WARNING: PBF output is not supported on this "
+                               "system but the outputfile has extension .pbf, "
+                               "automatically removing .pbf extension")
                 (base_osm, ext_osm) = os.path.splitext(base)
                 if ext_osm == '.osm':
                     params.outputFile = base
                 else:
                     params.outputFile = base + '.osm'
         if params.sqlQuery:
-            logging.warning("WARNING: You specified a query with --sql " +
-                            "but you are not using a database source")
+            logger.warning("WARNING: You specified a query with --sql "
+                           "but you are not using a database source")
 
     if not params.forceOverwrite and os.path.exists(params.outputFile):
-        parser.error("ERROR: output file '%s' exists" % (params.outputFile))
-    
+        parser.error("ERROR: output file '%s' exists" % params.outputFile)
+
     return params
 
 
-def load_translation_object(translation_module):
-    import_translation_module = None
+def load_translation_object(logger, translation_module):
     translation_object = None
 
     if translation_module:
@@ -201,9 +204,7 @@ def load_translation_object(translation_module):
         else:
             # first check translations in the subdir translations of cwd
             sys.path.insert(0, os.path.join(os.getcwd(), "translations"))
-            # then check subdir of script dir
-            sys.path.insert(1, os.path.join(os.path.dirname(__file__), "translations"))
-            # (the cwd will also be checked implicityly)
+            # (the cwd will also be checked implicitly)
 
         # strip .py if present, as import wants just the module name
         if ext == '.py':
@@ -213,65 +214,72 @@ def load_translation_object(translation_module):
         try:
             imported_module = __import__(translation_module)
         except ImportError as e:
-            logging.error("Could not load translation method '%s'. Translation "
-                          "script must be in your current directory, or in the "
-                          "translations/ subdirectory of your current or ogr2osm.py "
-                          "directory. The following directories have been considered: %s"
-                          % (translation_module, str(sys.path)))
+            logger.error("Could not load translation method '%s'. Translation "
+                         "script must be in your current directory, or in the "
+                         "translations/ subdirectory of your current directory. "
+                         "The following directories have been considered: %s",
+                         translation_module, str(sys.path))
         except SyntaxError as e:
-            logging.error("Syntax error in '%s'. Translation script is malformed:\n%s"
-                          % (translation_module, e))
-    
+            logger.error("Syntax error in '%s'. Translation script is malformed:\n%s",
+                         translation_module, e)
+
         for class_name in [ d for d in dir(imported_module) \
                                     if d != 'TranslationBase' and not d.startswith('__') ]:
             translation_class = getattr(imported_module, class_name)
 
             if inspect.isclass(translation_class) and \
                issubclass(translation_class, TranslationBase):
-                logging.info('Found valid translation class %s' % class_name)
+                logger.info('Found valid translation class %s', class_name)
                 setattr(sys.modules[__name__], class_name, translation_class)
                 translation_object = translation_class()
                 break
 
     if not translation_object:
         if translation_module:
-            logging.warning('WARNING: translation file does not contain a valid translation class')
-            logging.warning('Falling back to DEFAULT translations')
+            logger.warning('WARNING: translation file does not contain a valid translation class')
+            logger.warning('Falling back to DEFAULT translations')
         else:
-            logging.info('Using default translations')
+            logger.info('Using default translations')
         translation_object = TranslationBase()
-    
+
     return translation_object
 
 
 def main():
-    params = parse_commandline()
+    logger = logging.getLogger(__program__)
+    logger.setLevel(logging.DEBUG)
+    logger.addHandler(logging.StreamHandler())
 
-    translation_object = load_translation_object(params.translationmodule)
+    params = parse_commandline(logger)
+
+    translation_object = load_translation_object(logger, params.translationmodule)
 
     OsmId.set_id(params.id, params.positiveId)
     if params.idfile:
         OsmId.load_id(params.idfile)
 
-    logging.info("Preparing to convert '%s' to '%s'." % (params.source, params.outputFile))
+    logger.info("Preparing to convert '%s' to '%s'.", params.source, params.outputFile)
 
-    osmdata = OsmData(translation_object, params.roundingDigits, params.maxNodesPerWay, params.addBounds)
+    osmdata = OsmData(translation_object, \
+                      params.roundingDigits, params.maxNodesPerWay, params.addBounds)
     # create datasource and process data
     datasource = OgrDatasource(translation_object, \
-                               params.sourcePROJ4, params.sourceEPSG, params.gisorder, params.encoding)
+                               params.sourcePROJ4, params.sourceEPSG, params.gisorder, \
+                               params.encoding)
     datasource.open_datasource(params.source, not params.noMemoryCopy)
     datasource.set_query(params.sqlQuery)
     osmdata.process(datasource)
     #create datawriter and write OSM data
     datawriter = None
     if params.pbf:
-        datawriter = PbfDataWriter(params.outputFile, params.addVersion, params.addTimestamp)
+        datawriter = PbfDataWriter(params.outputFile, params.addVersion, params.addTimestamp, \
+                                   params.suppressEmptyTags)
     else:
         datawriter = OsmDataWriter(params.outputFile, params.neverUpload, params.noUploadFalse, \
                                    params.neverDownload, params.locked, params.addVersion, \
-                                   params.addTimestamp, params.significantDigits)
+                                   params.addTimestamp, params.significantDigits, \
+                                   params.suppressEmptyTags)
     osmdata.output(datawriter)
 
     if params.saveid:
         OsmId.save_id(params.saveid)
-
